@@ -4,3 +4,6 @@
 ## ----Rmd, eval=FALSE-----------------------------------------------------
 #  RNAseqNetUsersGuide(html = FALSE)
 
+## ----sessionInfo---------------------------------------------------------
+sessionInfo()
+
